@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.7.2.1 1999/09/16 21:08:55 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -43,7 +43,7 @@ int
 main (int argc, char *argv [])
 {
 	glibtop_netload netload;
-	unsigned method, count, port;
+	unsigned method, count, port, i;
 	struct in_addr addr, subnet;
 	char *address_string, *subnet_string;
 	char buffer [BUFSIZ];
