@@ -27,6 +27,8 @@
 #include <glibtop/cpu.h>
 #include <glibtop/xmalloc.h>
 
+#include <math.h>
+
 int
 main (int argc, char *argv [])
 {
@@ -65,7 +67,7 @@ main (int argc, char *argv [])
 	memset (separator, '-', 91);
 	separator [92] = '\0';
 
-	sprintf (buffer, _("Ticks (%ld per second):"), frequency);
+	sprintf (buffer, _("Ticks (%d per second):"), frequency);
 
 	printf ("\n\n%-26s %12s %12s %12s %12s %12s\n%s\n", buffer,
 		_("Total"), _("User"), _("Nice"), _("Sys"), _("Idle"), separator);
