@@ -24,7 +24,12 @@
 #ifndef __GLIBTOP_H__
 #define __GLIBTOP_H__
 
+#ifndef _IN_LIBGTOP
+#include <glibtop-config.h>
+#endif
+
 #include <glibtop/global.h>
+#include <glibtop/limits.h>
 
 #include <glibtop_server.h>
 #include <glibtop/types.h>
@@ -33,10 +38,6 @@
 #include <glibtop_machine.h>
 #endif
 
-#ifndef GLIBTOP_MOUNTENTRY_LEN
-#define GLIBTOP_MOUNTENTRY_LEN	79
-#endif
-
 typedef struct _glibtop		glibtop;
 
 #include <glibtop/sysdeps.h>
@@ -63,6 +64,7 @@ struct _glibtop
 	unsigned long server_port;	/* Port on which daemon is listening */
 	glibtop_sysdeps sysdeps;	/* Detailed feature list */
 	glibtop_sysdeps required;	/* Required feature list */
+	glibtop_sysdeps wanted;		/* We only want this features */
 	pid_t pid;			/* PID of the server */
 };
 
