@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -41,28 +43,27 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_XCPU_NICE	8
 #define GLIBTOP_XCPU_SYS	9
 #define GLIBTOP_XCPU_IDLE	10
+#define GLIBTOP_XCPU_FLAGS	11
 
-#define GLIBTOP_MAX_CPU		11
-
-/* Nobody should really be using more than 4 processors. */
-#define GLIBTOP_NCPU		4
+#define GLIBTOP_MAX_CPU		12
 
 typedef struct _glibtop_cpu	glibtop_cpu;
 
 struct _glibtop_cpu
 {
-	u_int64_t	flags,
-		total,				/* GLIBTOP_CPU_TOTAL		*/
-		user,				/* GLIBTOP_CPU_USER		*/
-		nice,				/* GLIBTOP_CPU_NICE		*/
-		sys,				/* GLIBTOP_CPU_SYS		*/
-		idle,				/* GLIBTOP_CPU_IDLE		*/
-		frequency,			/* GLIBTOP_CPU_FREQUENCY	*/
-		xcpu_total [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_TOTAL		*/
-		xcpu_user [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_USER		*/
-		xcpu_nice [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_NICE		*/
-		xcpu_sys  [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_SYS		*/
-		xcpu_idle [GLIBTOP_NCPU];	/* GLIBTOP_XCPU_IDLE		*/
+    u_int64_t	flags,
+	total,				/* GLIBTOP_CPU_TOTAL		*/
+	user,				/* GLIBTOP_CPU_USER		*/
+	nice,				/* GLIBTOP_CPU_NICE		*/
+	sys,				/* GLIBTOP_CPU_SYS		*/
+	idle,				/* GLIBTOP_CPU_IDLE		*/
+	frequency,			/* GLIBTOP_CPU_FREQUENCY	*/
+	xcpu_total [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_TOTAL		*/
+	xcpu_user [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_USER		*/
+	xcpu_nice [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_NICE		*/
+	xcpu_sys  [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_SYS		*/
+	xcpu_idle [GLIBTOP_NCPU],	/* GLIBTOP_XCPU_IDLE		*/
+	xcpu_flags;			/* GLIBTOP_XCPU_FLAGS		*/
 };
 
 #define glibtop_get_cpu(cpu)	glibtop_get_cpu_l(glibtop_global_server, cpu)
