@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -29,12 +31,25 @@
 
 BEGIN_LIBGTOP_DECLS
 
-#define GLIBTOP_PROC_STATE_CMD		0
-#define GLIBTOP_PROC_STATE_STATE	1
-#define GLIBTOP_PROC_STATE_UID		2
-#define GLIBTOP_PROC_STATE_GID		3
+#define GLIBTOP_PROC_STATE_CMD			0
+#define GLIBTOP_PROC_STATE_STATE		1
+#define GLIBTOP_PROC_STATE_UID			2
+#define GLIBTOP_PROC_STATE_GID			3
+#define GLIBTOP_PROC_STATE_RUID			4
+#define GLIBTOP_PROC_STATE_RGID			5
+#define GLIBTOP_PROC_STATE_HAS_CPU		6
+#define GLIBTOP_PROC_STATE_PROCESSOR		7
+#define GLIBTOP_PROC_STATE_LAST_PROCESSOR	8
 
-#define GLIBTOP_MAX_PROC_STATE		4
+#define GLIBTOP_MAX_PROC_STATE			9
+
+/* Constants for the `state' field. */
+#define GLIBTOP_PROCESS_RUNNING			1
+#define GLIBTOP_PROCESS_INTERRUPTIBLE		2
+#define GLIBTOP_PROCESS_UNINTERRUPTIBLE		4
+#define GLIBTOP_PROCESS_ZOMBIE			8
+#define GLIBTOP_PROCESS_STOPPED			16
+#define GLIBTOP_PROCESS_SWAPPING		32
 
 typedef struct _glibtop_proc_state	glibtop_proc_state;
 
@@ -42,18 +57,24 @@ typedef struct _glibtop_proc_state	glibtop_proc_state;
 
 struct _glibtop_proc_state
 {
-	u_int64_t flags;
-	char cmd[40],		/* basename of executable file in 
+    u_int64_t flags;
+    char cmd[40];		/* basename of executable file in 
 				 * call to exec(2) */
-		state;		/* single-char code for process state
-				 * (S=sleeping) */
-	/* NOTE: when porting the library, TRY HARD to implement the
-	 *       following two fields. */
-	/* IMPORTANT NOTICE: For security reasons, it is extremely important
-	 *                   only to set the flags value for those two
-	 *                   fields if their values are corrent ! */
-	int uid,		/* UID of process */
-		gid;		/* GID of process */
+    unsigned state;		/* process state */
+    /* NOTE: when porting the library, TRY HARD to implement the
+     *       following two fields. */
+    /* IMPORTANT NOTICE: For security reasons, it is extremely important
+     *                   only to set the flags value for those two
+     *                   fields if their values are corrent ! */
+    int uid,			/* effective UID of process */
+	gid,			/* effective GID of process */
+	ruid,			/* real UID of process */
+	rgid;			/* real GID of process */
+    /* SMP values. */
+    int has_cpu,
+	processor,
+	last_processor;
+
 };
 
 #define glibtop_get_proc_state(p1, p2)	glibtop_get_proc_state_l(glibtop_global_server, p1, p2)
