@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+
 /* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
@@ -30,8 +32,9 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_TYPE_ULONG	2
 #define GLIBTOP_TYPE_DOUBLE	3
 #define GLIBTOP_TYPE_INT	4
-#define GLIBTOP_TYPE_CHAR	5
-#define GLIBTOP_TYPE_STRING	6
+#define GLIBTOP_TYPE_UNSIGNED	5
+#define GLIBTOP_TYPE_CHAR	6
+#define GLIBTOP_TYPE_STRING	7
 
 END_LIBGTOP_DECLS
 
