@@ -26,12 +26,12 @@
 void
 handle_slave_connection (int input, int output)
 {
-	glibtop *server G_GNUC_UNUSED = glibtop_global_server;
-	int64_t *param_ptr G_GNUC_UNUSED;
-	const void *ptr G_GNUC_UNUSED;
+	glibtop *server = glibtop_global_server;
+	int64_t *param_ptr;
+	const void *ptr;
 
-	unsigned short max_len G_GNUC_UNUSED;
-	pid_t pid G_GNUC_UNUSED;
+	unsigned short max_len;
+	pid_t pid;
 
 	glibtop_response _resp, *resp = &_resp;
 	glibtop_command _cmnd, *cmnd = &_cmnd;
@@ -119,16 +119,16 @@ handle_slave_command (glibtop_command *cmnd, glibtop_response *resp,
 		      const void *parameter)
 {
 	glibtop *server = glibtop_global_server;
-	unsigned device G_GNUC_UNUSED;
-	pid_t pid G_GNUC_UNUSED;
+	unsigned device;
+	pid_t pid;
 
 	switch (cmnd->command) {
 	case GLIBTOP_CMND_SYSDEPS:
 		memcpy (&resp->u.sysdeps, &server->sysdeps, 
 			sizeof (glibtop_sysdeps));
 		resp->u.sysdeps.features = glibtop_server_features;
-		resp->u.sysdeps.flags = glibtop_server_features |
-		  (1L << GLIBTOP_SYSDEPS_FEATURES);
+		resp->u.sysdeps.pointer_size = sizeof (void*)*8;
+		resp->u.sysdeps.flags = glibtop_server_features;
 		resp->offset = _offset_union (sysdeps);
 		break;
 #if GLIBTOP_SUID_CPU
