@@ -46,7 +46,7 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 
 /* #define KERNEL to get declaration of `struct msginfo'. */
 
-#if (defined(__FreeBSD__) && (__FreeBSD_version < 410000)) || (defined __bsdi__)
+#if (defined __FreeBSD__) || (defined __bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -76,7 +76,7 @@ static struct nlist nlst [] = {
 void
 glibtop_init_msg_limits_p (glibtop *server)
 {
-	if (kvm_nlist (server->machine.kd, nlst) < 0) {
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (msg_limits)");
 		return;
 	}
