@@ -34,10 +34,10 @@
 #if (!defined __OpenBSD__) && (!defined __bsdi__)
 #include <sys/user.h>
 #endif
-#if !defined(__bsdi__) && !(defined(__FreeBSD__) && defined(__alpha__))
+#ifndef __bsdi__
 #include <machine/pcb.h>
 #endif
-#if defined(__FreeBSD__) && !defined(__alpha__)
+#ifdef __FreeBSD__
 #include <machine/tss.h>
 #endif
 
@@ -155,7 +155,6 @@ glibtop_get_proc_kernel_p (glibtop *server,
 		       (char *) &pcb, sizeof (pcb)) == sizeof (pcb))
 		{
 #ifdef __FreeBSD__
-#ifndef __alpha__
 #if (__FreeBSD_version >= 300003)
 			buf->kstk_esp = (u_int64_t) pcb.pcb_esp;
 			buf->kstk_eip = (u_int64_t) pcb.pcb_eip;
@@ -163,9 +162,6 @@ glibtop_get_proc_kernel_p (glibtop *server,
 			buf->kstk_esp = (u_int64_t) pcb.pcb_ksp;
 			buf->kstk_eip = (u_int64_t) pcb.pcb_pc;
 #endif
-#else
-			/*xxx FreeBSD/Alpha? */
-#endif
 #else
 			buf->kstk_esp = (u_int64_t) pcb.pcb_tss.tss_esp0;
 #ifdef __bsdi__
