@@ -38,11 +38,9 @@ static const unsigned long _glibtop_sysdeps_proc_uid_groups =
 #if LIBGTOP_VERSION_CODE >= 1001000
 #if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
 (1L << GLIBTOP_PROC_UID_NGROUPS) + (1L << GLIBTOP_PROC_UID_GROUPS);
-#else
-0L;
 #endif
-#else /* LIBGTOP_VERSION_CODE < 1001000 */
-0L;
+#else
+0;
 #endif
 
 /* Init function. */
