@@ -46,7 +46,7 @@ glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 
 /* #define KERNEL to get declaration of `struct seminfo'. */
 
-#if (defined(__FreeBSD__) && (__FreeBSD_version < 410000)) || defined(__bsdi__)
+#if defined(__FreeBSD__) || defined(__bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -78,7 +78,7 @@ static struct nlist nlst [] = {
 void
 glibtop_init_sem_limits_p (glibtop *server)
 {
-	if (kvm_nlist (server->machine.kd, nlst) < 0) {
+	if (kvm_nlist (server->machine.kd, nlst) != 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (sem_limits)");
 		return;
 	}
