@@ -27,6 +27,7 @@ glibtop_guile_names_proc_args (void)
 static SCM
 glibtop_guile_types_proc_args (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_args [0]),
@@ -89,6 +90,7 @@ glibtop_guile_names_proc_time (void)
 static SCM
 glibtop_guile_types_proc_time (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_time [0]),
@@ -100,12 +102,9 @@ glibtop_guile_types_proc_time (void)
 			gh_ulong2scm (glibtop_types_proc_time [6]),
 			gh_ulong2scm (glibtop_types_proc_time [7]),
 			gh_ulong2scm (glibtop_types_proc_time [8]),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_proc_time [9]),
-			 gh_ulong2scm (4)),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_proc_time [10]),
-			 gh_ulong2scm (4)),
+			gh_ulong2scm (glibtop_types_proc_time [9]),
+			gh_ulong2scm (glibtop_types_proc_time [10]),
+			gh_ulong2scm (glibtop_types_proc_time [11]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -165,6 +164,7 @@ glibtop_guile_names_proc_segment (void)
 static SCM
 glibtop_guile_types_proc_segment (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_segment [0]),
@@ -175,6 +175,15 @@ glibtop_guile_types_proc_segment (void)
 			gh_ulong2scm (glibtop_types_proc_segment [5]),
 			gh_ulong2scm (glibtop_types_proc_segment [6]),
 			gh_ulong2scm (glibtop_types_proc_segment [7]),
+			gh_ulong2scm (glibtop_types_proc_segment [8]),
+			gh_ulong2scm (glibtop_types_proc_segment [9]),
+			gh_ulong2scm (glibtop_types_proc_segment [10]),
+			gh_ulong2scm (glibtop_types_proc_segment [11]),
+			gh_ulong2scm (glibtop_types_proc_segment [12]),
+			gh_ulong2scm (glibtop_types_proc_segment [13]),
+			gh_ulong2scm (glibtop_types_proc_segment [14]),
+			gh_ulong2scm (glibtop_types_proc_segment [15]),
+			gh_ulong2scm (glibtop_types_proc_segment [16]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -234,6 +243,7 @@ glibtop_guile_names_netload (void)
 static SCM
 glibtop_guile_types_netload (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_netload [0]),
@@ -309,6 +319,7 @@ glibtop_guile_names_cpu (void)
 static SCM
 glibtop_guile_types_cpu (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_cpu [0]),
@@ -317,21 +328,12 @@ glibtop_guile_types_cpu (void)
 			gh_ulong2scm (glibtop_types_cpu [3]),
 			gh_ulong2scm (glibtop_types_cpu [4]),
 			gh_ulong2scm (glibtop_types_cpu [5]),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_cpu [6]),
-			 gh_ulong2scm (4)),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_cpu [7]),
-			 gh_ulong2scm (4)),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_cpu [8]),
-			 gh_ulong2scm (4)),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_cpu [9]),
-			 gh_ulong2scm (4)),
-			gh_cons
-			(gh_ulong2scm (glibtop_types_cpu [10]),
-			 gh_ulong2scm (4)),
+			gh_ulong2scm (glibtop_types_cpu [6]),
+			gh_ulong2scm (glibtop_types_cpu [7]),
+			gh_ulong2scm (glibtop_types_cpu [8]),
+			gh_ulong2scm (glibtop_types_cpu [9]),
+			gh_ulong2scm (glibtop_types_cpu [10]),
+			gh_ulong2scm (glibtop_types_cpu [11]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -391,6 +393,7 @@ glibtop_guile_names_sysdeps (void)
 static SCM
 glibtop_guile_types_sysdeps (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (SCM_UNDEFINED);
@@ -452,6 +455,7 @@ glibtop_guile_names_fsusage (void)
 static SCM
 glibtop_guile_types_fsusage (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_fsusage [0]),
@@ -518,6 +522,7 @@ glibtop_guile_names_mountlist (void)
 static SCM
 glibtop_guile_types_mountlist (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_mountlist [0]),
@@ -582,6 +587,7 @@ glibtop_guile_names_ppp (void)
 static SCM
 glibtop_guile_types_ppp (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_ppp [0]),
@@ -646,6 +652,7 @@ glibtop_guile_names_proclist (void)
 static SCM
 glibtop_guile_types_proclist (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proclist [0]),
@@ -710,6 +717,7 @@ glibtop_guile_names_proc_signal (void)
 static SCM
 glibtop_guile_types_proc_signal (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_cons
@@ -783,6 +791,7 @@ glibtop_guile_names_proc_map (void)
 static SCM
 glibtop_guile_types_proc_map (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_map [0]),
@@ -847,6 +856,7 @@ glibtop_guile_names_proc_mem (void)
 static SCM
 glibtop_guile_types_proc_mem (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_mem [0]),
@@ -914,10 +924,12 @@ glibtop_guile_names_uptime (void)
 static SCM
 glibtop_guile_types_uptime (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_uptime [0]),
 			gh_ulong2scm (glibtop_types_uptime [1]),
+			gh_ulong2scm (glibtop_types_uptime [0]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -977,12 +989,18 @@ glibtop_guile_names_proc_state (void)
 static SCM
 glibtop_guile_types_proc_state (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_state [0]),
 			gh_ulong2scm (glibtop_types_proc_state [0]),
 			gh_ulong2scm (glibtop_types_proc_state [0]),
 			gh_ulong2scm (glibtop_types_proc_state [1]),
+			gh_ulong2scm (glibtop_types_proc_state [2]),
+			gh_ulong2scm (glibtop_types_proc_state [3]),
+			gh_ulong2scm (glibtop_types_proc_state [4]),
+			gh_ulong2scm (glibtop_types_proc_state [5]),
+			gh_ulong2scm (glibtop_types_proc_state [6]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -1042,6 +1060,7 @@ glibtop_guile_names_proc_kernel (void)
 static SCM
 glibtop_guile_types_proc_kernel (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_kernel [0]),
@@ -1112,6 +1131,7 @@ glibtop_guile_names_proc_uid (void)
 static SCM
 glibtop_guile_types_proc_uid (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_proc_uid [0]),
@@ -1126,6 +1146,12 @@ glibtop_guile_types_proc_uid (void)
 			gh_ulong2scm (glibtop_types_proc_uid [9]),
 			gh_ulong2scm (glibtop_types_proc_uid [10]),
 			gh_ulong2scm (glibtop_types_proc_uid [11]),
+			gh_ulong2scm (glibtop_types_proc_uid [12]),
+			gh_ulong2scm (glibtop_types_proc_uid [13]),
+			gh_ulong2scm (glibtop_types_proc_uid [14]),
+			gh_ulong2scm (glibtop_types_proc_uid [15]),
+			gh_ulong2scm (glibtop_types_proc_uid [16]),
+			gh_ulong2scm (glibtop_types_proc_uid [17]),
 			SCM_UNDEFINED);
 
 	return list;
@@ -1185,6 +1211,7 @@ glibtop_guile_names_sem_limits (void)
 static SCM
 glibtop_guile_types_sem_limits (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_sem_limits [0]),
@@ -1256,6 +1283,7 @@ glibtop_guile_names_msg_limits (void)
 static SCM
 glibtop_guile_types_msg_limits (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_msg_limits [0]),
@@ -1324,6 +1352,7 @@ glibtop_guile_names_shm_limits (void)
 static SCM
 glibtop_guile_types_shm_limits (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_shm_limits [0]),
@@ -1390,6 +1419,7 @@ glibtop_guile_names_swap (void)
 static SCM
 glibtop_guile_types_swap (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_swap [0]),
@@ -1456,6 +1486,7 @@ glibtop_guile_names_loadavg (void)
 static SCM
 glibtop_guile_types_loadavg (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_cons
@@ -1523,6 +1554,7 @@ glibtop_guile_names_mem (void)
 static SCM
 glibtop_guile_types_mem (void)
 {
+	int i;
 	SCM list;
 
 	list = gh_list (gh_ulong2scm (glibtop_types_mem [0]),
