@@ -3,7 +3,7 @@
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
-   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
+   Contributed by Martin Baulig <martin@home-of-linux.org>, March 1999.
 
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -21,45 +21,37 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
-#include <glibtop/error.h>
+#include <glibtop.h>
 #include <glibtop/loadavg.h>
 
-#include "kernel.h"
+#include <glibtop_private.h>
 
 static const unsigned long _glibtop_sysdeps_loadavg =
-(1 << GLIBTOP_LOADAVG_LOADAVG) + (1 << GLIBTOP_LOADAVG_NR_RUNNING) +
-(1 << GLIBTOP_LOADAVG_NR_TASKS) + (1 << GLIBTOP_LOADAVG_LAST_PID);
+(1L << GLIBTOP_LOADAVG_LOADAVG);
 
 /* Init function. */
 
 void
 glibtop_init_loadavg_s (glibtop *server)
 {
-	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
+    server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
 
-/* Provides load load averange. */
+/* Provides load averange. */
 
 void
 glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 {
-	union table tbl;
-	
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_LOADAVG, 0);
+    libgtop_stat_t stat;
 
-	memset (buf, 0, sizeof (glibtop_loadavg));
+    memset (buf, 0, sizeof (glibtop_loadavg));
 
-	if (table (TABLE_LOADAVG, &tbl, NULL))
-		glibtop_error_io_r (server, "table(TABLE_LOADAVG)");
-	
-	buf->flags = _glibtop_sysdeps_loadavg;
+    if (glibtop_get_proc_data_stat_s (server, &stat))
+	return;
 
-	buf->loadavg [0] = tbl.loadavg.loadavg [0];
-	buf->loadavg [1] = tbl.loadavg.loadavg [1];
-	buf->loadavg [2] = tbl.loadavg.loadavg [2];
+    buf->loadavg [0] = stat.loadavg [0];
+    buf->loadavg [1] = stat.loadavg [1];
+    buf->loadavg [2] = stat.loadavg [2];
 
-	buf->nr_running = tbl.loadavg.nr_running;
-	buf->nr_tasks = tbl.loadavg.nr_tasks;
-	buf->last_pid = tbl.loadavg.last_pid;
+    buf->flags = _glibtop_sysdeps_loadavg;
 }
