@@ -3,7 +3,7 @@
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
-   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
+   Contributed by Martin Baulig <martin@home-of-linux.org>, March 1999.
 
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -21,24 +21,22 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
-#include <glibtop/error.h>
+#include <glibtop.h>
 #include <glibtop/mem.h>
 
-#include "kernel.h"
+#include <glibtop_private.h>
 
 static const unsigned long _glibtop_sysdeps_mem =
-(1 << GLIBTOP_MEM_TOTAL) + (1 << GLIBTOP_MEM_USED) +
-(1 << GLIBTOP_MEM_FREE) + (1 << GLIBTOP_MEM_SHARED) +
-(1 << GLIBTOP_MEM_BUFFER) + (1 << GLIBTOP_MEM_CACHED) +
-(1 << GLIBTOP_MEM_USER);
+(1L << GLIBTOP_MEM_TOTAL) + (1L << GLIBTOP_MEM_USED) +
+(1L << GLIBTOP_MEM_FREE) + (1L << GLIBTOP_MEM_SHARED) +
+(1L << GLIBTOP_MEM_BUFFER) + (1L << GLIBTOP_MEM_CACHED);
 
 /* Init function. */
 
 void
 glibtop_init_mem_s (glibtop *server)
 {
-	server->sysdeps.mem = _glibtop_sysdeps_mem;
+    server->sysdeps.mem = _glibtop_sysdeps_mem;
 }
 
 /* Provides information about memory usage. */
@@ -46,23 +44,19 @@ glibtop_init_mem_s (glibtop *server)
 void
 glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 {
-	union table tbl;
-	
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_MEM, 0);
+    libgtop_mem_t mem;
 
-	memset (buf, 0, sizeof (glibtop_mem));
+    memset (buf, 0, sizeof (glibtop_mem));
 
-	if (table (TABLE_MEM, &tbl, NULL))
-		glibtop_error_io_r (server, "table(TABLE_MEM)");
+    if (glibtop_get_proc_data_mem_s (server, &mem))
+	return;
 
-	buf->flags = _glibtop_sysdeps_mem;
+    buf->total = mem.totalram;
+    buf->used = mem.totalram - mem.freeram;
+    buf->free = mem.freeram;
+    buf->shared = mem.sharedram;
+    buf->buffer = mem.bufferram;
+    buf->cached = mem.cachedram;
 
-	buf->total  = tbl.mem.total;
-	buf->used   = tbl.mem.used;
-	buf->free   = tbl.mem.free;
-	buf->shared = tbl.mem.shared;
-	buf->buffer = tbl.mem.buffer;
-	buf->cached = tbl.mem.cached;
-
-	buf->user = buf->total - buf->free - buf->shared - buf->buffer;
+    buf->flags = _glibtop_sysdeps_mem;
 }
