@@ -22,23 +22,28 @@
 */
 
 #include <glibtop.h>
-#include <glibtop/error.h>
 #include <glibtop/prockernel.h>
 
-#include "kernel.h"
+#include <glibtop_private.h>
 
 static const unsigned long _glibtop_sysdeps_proc_kernel =
-(1 << GLIBTOP_PROC_KERNEL_K_FLAGS) + (1 << GLIBTOP_PROC_KERNEL_MIN_FLT) +
-(1 << GLIBTOP_PROC_KERNEL_MAJ_FLT) + (1 << GLIBTOP_PROC_KERNEL_CMIN_FLT) +
-(1 << GLIBTOP_PROC_KERNEL_CMAJ_FLT) + (1 << GLIBTOP_PROC_KERNEL_KSTK_ESP) +
-(1 << GLIBTOP_PROC_KERNEL_KSTK_EIP) + (1 << GLIBTOP_PROC_KERNEL_NWCHAN);
+(1L << GLIBTOP_PROC_KERNEL_MIN_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_MAJ_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_CMIN_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_CMAJ_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_KSTK_ESP) +
+(1L << GLIBTOP_PROC_KERNEL_KSTK_EIP);
+
+static const unsigned long _glibtop_sysdeps_proc_kernel_kernel =
+(1L << GLIBTOP_PROC_KERNEL_NWCHAN);
 
 /* Init function. */
 
 void
 glibtop_init_proc_kernel_s (glibtop *server)
 {
-	server->sysdeps.proc_kernel = _glibtop_sysdeps_proc_kernel;
+    server->sysdeps.proc_kernel = _glibtop_sysdeps_proc_kernel |
+	_glibtop_sysdeps_proc_kernel_kernel;
 }
 
 /* Provides detailed information about a process. */
@@ -47,22 +52,26 @@ void
 glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf,
 			   pid_t pid)
 {
-	union table tbl;
-	
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_KERNEL, 0);
-	
-	memset (buf, 0, sizeof (glibtop_proc_kernel));
-	
-	if (table (TABLE_PROC_KERNEL, &tbl, &pid))
-		glibtop_error_io_r (server, "table(TABLE_PROC_KERNEL)");
-	
-	buf->flags = _glibtop_sysdeps_proc_kernel;
-	
-	buf->min_flt = tbl.proc_kernel.min_flt;
-	buf->cmin_flt = tbl.proc_kernel.cmin_flt;
-	buf->maj_flt = tbl.proc_kernel.maj_flt;
-	buf->cmaj_flt = tbl.proc_kernel.cmaj_flt;
-	buf->kstk_esp = tbl.proc_kernel.kesp;
-	buf->kstk_eip = tbl.proc_kernel.keip;
-	buf->nwchan = tbl.proc_kernel.wchan;
+    libgtop_proc_state_t proc_state;
+    libgtop_proc_kernel_t proc_kernel;
+
+    memset (buf, 0, sizeof (glibtop_proc_kernel));
+
+    if (glibtop_get_proc_data_proc_state_s (server, &proc_state, pid))
+	return;
+
+    buf->min_flt = proc_state.min_flt;
+    buf->maj_flt = proc_state.maj_flt;
+    buf->cmin_flt = proc_state.cmin_flt;
+    buf->cmaj_flt = proc_state.cmaj_flt;
+    buf->kstk_esp = proc_state.kesp;
+    buf->kstk_eip = proc_state.keip;
+
+    buf->flags = _glibtop_sysdeps_proc_kernel;
+
+    if (glibtop_get_proc_data_proc_kernel_s (server, &proc_kernel, pid))
+	return;
+
+    buf->nwchan = proc_kernel.wchan;
+    buf->flags |= _glibtop_sysdeps_proc_kernel_kernel;
 }
