@@ -1,4 +1,4 @@
-/* $Id: procsignal.c,v 1.9 1999/02/23 11:44:42 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,21 +22,22 @@
 */
 
 #include <glibtop.h>
-#include <glibtop/error.h>
 #include <glibtop/procsignal.h>
 
-#include "kernel.h"
+#include <glibtop_private.h>
 
 static const unsigned long _glibtop_sysdeps_proc_signal =
-(1 << GLIBTOP_PROC_SIGNAL_SIGNAL) + (1 << GLIBTOP_PROC_SIGNAL_BLOCKED) +
-(1 << GLIBTOP_PROC_SIGNAL_SIGIGNORE) + (1 << GLIBTOP_PROC_SIGNAL_SIGCATCH);
+(1L << GLIBTOP_PROC_SIGNAL_SIGNAL) +
+(1L << GLIBTOP_PROC_SIGNAL_BLOCKED) +
+(1L << GLIBTOP_PROC_SIGNAL_SIGIGNORE) +
+(1L << GLIBTOP_PROC_SIGNAL_SIGCATCH);
 
 /* Init function. */
 
 void
 glibtop_init_proc_signal_s (glibtop *server)
 {
-	server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
+    server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
 }
 
 /* Provides detailed information about a process. */
@@ -45,19 +46,20 @@ void
 glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf,
 			   pid_t pid)
 {
-	union table tbl;
+    libgtop_proc_signal_t proc_signal;
+    int i;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);
+    memset (buf, 0, sizeof (glibtop_proc_signal));
 
-	memset (buf, 0, sizeof (glibtop_proc_signal));
+    if (glibtop_get_proc_data_proc_signal_s (server, &proc_signal, pid))
+	return;
 
-	if (table (TABLE_PROC_SIGNAL, &tbl, &pid))
-		glibtop_error_io_r (server, "table(TABLE_PROC_SIGNAL)");
+    for (i = 0; i < 1; i++) {
+	buf->signal [i] = proc_signal.signal [i];
+	buf->blocked [i] = proc_signal.blocked [i];
+	buf->sigignore [i] = proc_signal.ignore [i];
+	buf->sigcatch [i] = proc_signal.catch [i];
+    }
 
-	buf->flags = _glibtop_sysdeps_proc_signal;
-
-	buf->signal [0] = tbl.proc_signal.signal;
-	buf->blocked [0] = tbl.proc_signal.blocked;
-	buf->sigignore [0] = tbl.proc_signal.ignored;
-	buf->sigcatch [0] = tbl.proc_signal.caught;
+    buf->flags = _glibtop_sysdeps_proc_signal;
 }
