@@ -22,24 +22,27 @@
 */
 
 #include <glibtop.h>
-#include <glibtop/error.h>
 #include <glibtop/proctime.h>
 
-#include "kernel.h"
+#include <glibtop_private.h>
 
 static const unsigned long _glibtop_sysdeps_proc_time =
-(1 << GLIBTOP_PROC_TIME_UTIME) + (1 << GLIBTOP_PROC_TIME_CUTIME) +
-(1 << GLIBTOP_PROC_TIME_STIME) + (1 << GLIBTOP_PROC_TIME_CSTIME) +
-(1 << GLIBTOP_PROC_TIME_RTIME) + (1 << GLIBTOP_PROC_TIME_FREQUENCY) +
-(1 << GLIBTOP_PROC_TIME_TIMEOUT) + (1 << GLIBTOP_PROC_TIME_IT_REAL_VALUE) +
-(1 << GLIBTOP_PROC_TIME_START_TIME);
+(1L << GLIBTOP_PROC_TIME_UTIME) + (1L << GLIBTOP_PROC_TIME_STIME) +
+(1L << GLIBTOP_PROC_TIME_CUTIME) + (1L << GLIBTOP_PROC_TIME_CSTIME) +
+(1L << GLIBTOP_PROC_TIME_START_TIME) + (1L << GLIBTOP_PROC_TIME_FREQUENCY);
+
+static const unsigned long _glibtop_sysdeps_proc_time_smp =
+(1L << GLIBTOP_PROC_TIME_XCPU_UTIME) + (1L << GLIBTOP_PROC_TIME_XCPU_STIME);
 
 /* Init function. */
 
 void
 glibtop_init_proc_time_s (glibtop *server)
 {
-	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
+    server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
+
+    if (server->ncpu)
+	server->sysdeps.proc_time |= _glibtop_sysdeps_proc_time_smp;
 }
 
 /* Provides detailed information about a process. */
@@ -48,26 +51,29 @@ void
 glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
-	union table tbl;
+    libgtop_proc_state_t proc_state;
+    int i;
 
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_TIME, 0);
+    memset (buf, 0, sizeof (glibtop_proc_time));
 
-	memset (buf, 0, sizeof (glibtop_proc_time));
+    if (glibtop_get_proc_data_proc_state_s (server, &proc_state, pid))
+	return;
 
-	if (table (TABLE_PROC_TIME, &tbl, &pid))
-	  glibtop_error_io_r (server, "table(TABLE_PROC_TIME)");
+    buf->start_time = proc_state.start_time;
+    buf->utime = proc_state.utime;
+    buf->stime = proc_state.stime;
+    buf->cutime = proc_state.cutime;
+    buf->cstime = proc_state.cstime;
 
-	buf->utime = tbl.proc_time.utime;
-	buf->stime = tbl.proc_time.stime;
+    buf->frequency = 100;
 
-	buf->rtime = buf->utime + buf->stime;
+    buf->flags = _glibtop_sysdeps_proc_time;
 
-	buf->cutime = tbl.proc_time.cutime;
-	buf->cstime = tbl.proc_time.cstime;
+    for (i = 0; i < server->ncpu; i++) {
+	buf->xcpu_utime [i] = proc_state.per_cpu_utime [i];
+	buf->xcpu_stime [i] = proc_state.per_cpu_stime [i];
+    }
 
-	buf->frequency = 100;
-
-	buf->timeout = tbl.proc_time.timeout;
-	buf->it_real_value = tbl.proc_time.it_real_value;
-	buf->start_time = tbl.proc_time.start_time;
+    if (server->ncpu)
+	buf->flags |= _glibtop_sysdeps_proc_time_smp;
 }
