@@ -3,7 +3,7 @@
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
-   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
+   Contributed by Martin Baulig <martin@home-of-linux.org>, March 1999.
 
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -27,16 +27,16 @@
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1 << GLIBTOP_IPC_SHMMAX) + (1 << GLIBTOP_IPC_SHMMIN) +
-(1 << GLIBTOP_IPC_SHMMNI) + (1 << GLIBTOP_IPC_SHMSEG) +
-(1 << GLIBTOP_IPC_SHMALL);
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
+(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
+(1L << GLIBTOP_IPC_SHMALL);
 
 /* Init function. */
 
 void
 glibtop_init_shm_limits_s (glibtop *server)
 {
-	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 }
 
 /* Provides information about sysv ipc limits. */
@@ -44,19 +44,19 @@ glibtop_init_shm_limits_s (glibtop *server)
 void
 glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 {
-	struct shminfo	shminfo;
+    struct shminfo shminfo;
   
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
+    glibtop_init_s (&server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
 
-	memset (buf, 0, sizeof (glibtop_shm_limits));
+    memset (buf, 0, sizeof (glibtop_shm_limits));
   
-	buf->flags = _glibtop_sysdeps_shm_limits;
+    buf->flags = _glibtop_sysdeps_shm_limits;
   
-	shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
+    shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
   
-	buf->shmmax = shminfo.shmmax;
-	buf->shmmin = shminfo.shmmin;
-	buf->shmmni = shminfo.shmmni;
-	buf->shmseg = shminfo.shmseg;
-	buf->shmall = shminfo.shmall;
+    buf->shmmax = shminfo.shmmax;
+    buf->shmmin = shminfo.shmmin;
+    buf->shmmni = shminfo.shmmni;
+    buf->shmseg = shminfo.shmseg;
+    buf->shmall = shminfo.shmall;
 }
