@@ -1,4 +1,4 @@
-/* $Id: loadavg.c,v 1.13 1999/02/23 11:44:56 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,12 +26,12 @@
 #include <glibtop/loadavg.h>
 
 static const unsigned long _glibtop_sysdeps_loadavg =
-(1 << GLIBTOP_LOADAVG_LOADAVG);
+(1L << GLIBTOP_LOADAVG_LOADAVG);
 
 static const unsigned long _glibtop_sysdeps_loadavg_tasks =
-(1 << GLIBTOP_LOADAVG_NR_RUNNING) +
-(1 << GLIBTOP_LOADAVG_NR_TASKS) +
-(1 << GLIBTOP_LOADAVG_LAST_PID);
+(1L << GLIBTOP_LOADAVG_NR_RUNNING) +
+(1L << GLIBTOP_LOADAVG_NR_TASKS) +
+(1L << GLIBTOP_LOADAVG_LAST_PID);
 
 /* Init function. */
 
