@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.14.4.2 1999/11/28 11:57:11 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,7 +28,7 @@
 #include <sys/stat.h>
 
 static const unsigned long _glibtop_sysdeps_proc_state =
-(1L << GLIBTOP_PROC_STATE_CMD) + (1L << GLIBTOP_PROC_STATE_STATE);
+(1L << GLIBTOP_PROC_STATE_CMD);
 
 static const unsigned long _glibtop_sysdeps_proc_state_uid =
 (1L << GLIBTOP_PROC_STATE_UID) + (1L << GLIBTOP_PROC_STATE_GID);
@@ -47,7 +47,7 @@ glibtop_init_proc_state_s (glibtop *server)
 void
 glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 {
-	char buffer [BUFSIZ], *p;
+	char buffer [BUFSIZ], state, *p;
 	struct stat statb;
 	
 	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_STATE, 0);
@@ -59,7 +59,7 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 	 *                   values; NEVER set their flags values if this
 	 *                   is not the case !!! */
 
-	sprintf (buffer, "/proc/%d", pid);
+	sprintf (buffer, "/proc/%d/stat", pid);
 
 	if (stat (buffer, &statb))
 		return;
@@ -72,15 +72,13 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 
 	buf->flags = _glibtop_sysdeps_proc_state_uid;
 
-	sprintf (buffer, "/proc/%d", pid);
-
 	/* Now we read the remaining fields. */
 
 	if (proc_stat_to_buffer (buffer, pid))
 		return;
 
 	p = strrchr (buffer, ')'); *p = '\0';
-	buf->state = p [2];
+	state = p [2];
 
 	p = skip_token (buffer); p++;	/* pid */
 	if (*p++ != '(')
@@ -90,4 +88,29 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf, pid_t pid)
 	buf->cmd [sizeof (buf->cmd)-1] = 0;
 
 	buf->flags |= _glibtop_sysdeps_proc_state;
+
+	switch (state) {
+	case 'R':
+	    buf->state = GLIBTOP_PROCESS_RUNNING;
+	    break;
+	case 'S':
+	    buf->state = GLIBTOP_PROCESS_INTERRUPTIBLE;
+	    break;
+	case 'D':
+	    buf->state = GLIBTOP_PROCESS_UNINTERRUPTIBLE;
+	    break;
+	case 'Z':
+	    buf->state = GLIBTOP_PROCESS_ZOMBIE;
+	    break;
+	case 'T':
+	    buf->state = GLIBTOP_PROCESS_STOPPED;
+	    break;
+	case 'W':
+	    buf->state = GLIBTOP_PROCESS_SWAPPING;
+	    break;
+	default:
+	    return;
+	}
+
+	buf->flags |= (1L << GLIBTOP_PROC_STATE_STATE);
 }
