@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.17.2.2 1999/09/16 21:05:33 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,8 +28,9 @@
 static const unsigned long _glibtop_sysdeps_proc_time =
 (1L << GLIBTOP_PROC_TIME_UTIME) + (1L << GLIBTOP_PROC_TIME_CUTIME) +
 (1L << GLIBTOP_PROC_TIME_STIME) + (1L << GLIBTOP_PROC_TIME_CSTIME) +
-(1L << GLIBTOP_PROC_TIME_FREQUENCY) + (1L << GLIBTOP_PROC_TIME_TIMEOUT) +
-(1L << GLIBTOP_PROC_TIME_IT_REAL_VALUE) + (1L << GLIBTOP_PROC_TIME_START_TIME);
+(1L << GLIBTOP_PROC_TIME_RTIME) + (1L << GLIBTOP_PROC_TIME_FREQUENCY) +
+(1L << GLIBTOP_PROC_TIME_TIMEOUT) + (1L << GLIBTOP_PROC_TIME_IT_REAL_VALUE) +
+(1L << GLIBTOP_PROC_TIME_START_TIME);
 
 static const unsigned long _glibtop_sysdeps_proc_time_smp =
 (1L << GLIBTOP_PROC_TIME_XCPU_UTIME) + (1L << GLIBTOP_PROC_TIME_XCPU_STIME);
@@ -70,6 +71,8 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf, pid_t pid)
 	buf->cutime = strtoul (p, &p, 0);
 	buf->cstime = strtoul (p, &p, 0);
 
+	buf->rtime = buf->utime + buf->stime;
+
 	p = skip_multiple_token (p, 2);
 
 	buf->timeout = strtoul (p, &p, 0);
