@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.1.1.1.2.1 2001/02/14 23:07:41 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -55,7 +55,8 @@ glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf,
 		if (glibtop_get_proc_data_usage_s (server, &prusage, pid))
 			return;
 
-		buf->start_time = prusage.pr_create.tv_sec;
+		buf->start_time = prusage.pr_create.tv_sec * 1E+6 +
+			prusage.pr_create.tv_nsec / 1E+3;
 
 		buf->rtime = prusage.pr_rtime.tv_sec * 1E+6 +
 			prusage.pr_rtime.tv_nsec / 1E+3;
