@@ -27,9 +27,9 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_cpu =
-(1 << GLIBTOP_CPU_TOTAL) + (1 << GLIBTOP_CPU_USER) +
-(1 << GLIBTOP_CPU_NICE) + (1 << GLIBTOP_CPU_SYS) +
-(1 << GLIBTOP_CPU_IDLE) + (1 << GLIBTOP_CPU_FREQUENCY);
+(1L << GLIBTOP_CPU_TOTAL) + (1L << GLIBTOP_CPU_USER) +
+(1L << GLIBTOP_CPU_NICE) + (1L << GLIBTOP_CPU_SYS) +
+(1L << GLIBTOP_CPU_IDLE) + (1L << GLIBTOP_CPU_FREQUENCY);
 
 /* Provides information about cpu usage. */
 
@@ -39,7 +39,7 @@ glibtop_get_cpu_p (glibtop *server, glibtop_cpu *buf)
 	long cp_time [CPUSTATES], mp_time [NCPU][CPUSTATES];
 	int i;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_CPU), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_CPU), 0);
 	
 	memset (buf, 0, sizeof (glibtop_cpu));
 
