@@ -27,8 +27,8 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_mem =
-(1 << GLIBTOP_MEM_TOTAL) + (1 << GLIBTOP_MEM_USED) +
-(1 << GLIBTOP_MEM_FREE) + (1 << GLIBTOP_MEM_LOCKED);
+(1L << GLIBTOP_MEM_TOTAL) + (1L << GLIBTOP_MEM_USED) +
+(1L << GLIBTOP_MEM_FREE) + (1L << GLIBTOP_MEM_LOCKED);
 
 /* define pagetok in terms of pageshift */
 
@@ -39,7 +39,7 @@ static const unsigned long _glibtop_sysdeps_mem =
 void
 glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 {
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MEM), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MEM), 0);
 
 	memset (buf, 0, sizeof (glibtop_mem));
 	
