@@ -27,8 +27,8 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_mem =
-(1 << GLIBTOP_PROC_MEM_SIZE) + (1 << GLIBTOP_PROC_MEM_RSS) +
-(1 << GLIBTOP_PROC_MEM_RSS_RLIM);
+(1L << GLIBTOP_PROC_MEM_SIZE) + (1L << GLIBTOP_PROC_MEM_RSS) +
+(1L << GLIBTOP_PROC_MEM_RSS_RLIM);
 
 /* Provides detailed information about a process. */
 
@@ -38,7 +38,7 @@ glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf,
 {
 	struct proc *pp;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_MEM), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MEM), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_mem));
 
