@@ -27,8 +27,8 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_segment =
-(1 << GLIBTOP_PROC_SEGMENT_TEXT_RSS) +
-(1 << GLIBTOP_PROC_SEGMENT_DATA_RSS);
+(1L << GLIBTOP_PROC_SEGMENT_TEXT_RSS) +
+(1L << GLIBTOP_PROC_SEGMENT_DATA_RSS);
 
 /* Provides detailed information about a process. */
 
@@ -38,7 +38,7 @@ glibtop_get_proc_segment_p (glibtop *server, glibtop_proc_segment *buf,
 {
 	struct proc *pp;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_segment));
 
