@@ -27,7 +27,7 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_time =
-(1 << GLIBTOP_PROC_TIME_START_TIME) + (1 << GLIBTOP_PROC_TIME_UTIME);
+(1L << GLIBTOP_PROC_TIME_START_TIME) + (1L << GLIBTOP_PROC_TIME_UTIME);
 
 /* Provides detailed information about a process. */
 
@@ -37,7 +37,7 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 {
 	struct proc *pp;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_TIME), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_TIME), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_time));
 
