@@ -27,11 +27,11 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_uid =
-(1 << GLIBTOP_PROC_UID_UID) + (1 << GLIBTOP_PROC_UID_EUID) +
-(1 << GLIBTOP_PROC_UID_EGID) + (1 << GLIBTOP_PROC_UID_PID) +
-(1 << GLIBTOP_PROC_UID_PPID) + (1 << GLIBTOP_PROC_UID_PGRP) +
-(1 << GLIBTOP_PROC_UID_TPGID) + (1 << GLIBTOP_PROC_UID_PRIORITY) +
-(1 << GLIBTOP_PROC_UID_NICE);
+(1L << GLIBTOP_PROC_UID_UID) + (1L << GLIBTOP_PROC_UID_EUID) +
+(1L << GLIBTOP_PROC_UID_EGID) + (1L << GLIBTOP_PROC_UID_PID) +
+(1L << GLIBTOP_PROC_UID_PPID) + (1L << GLIBTOP_PROC_UID_PGRP) +
+(1L << GLIBTOP_PROC_UID_TPGID) + (1L << GLIBTOP_PROC_UID_PRIORITY) +
+(1L << GLIBTOP_PROC_UID_NICE);
 
 /* Provides detailed information about a process. */
 
@@ -41,7 +41,7 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 {
 	struct proc *pp;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_UID), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_UID), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_uid));
 
