@@ -31,7 +31,7 @@
 void
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SWAP), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
 
 	memset (buf, 0, sizeof (glibtop_swap));
 }
